@@ -3,7 +3,7 @@ package HTML::FormBuilder;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use HTML::FormBuilder::FieldSet;
@@ -43,8 +43,8 @@ has after_form => (
     });
 
 sub BUILDARGS {
-    my $class = shift;
-    my %args = (@_ % 2) ? %{$_[0]} : @_;
+    my ($class, @args) = @_;
+    my %args = (@args % 2) ? %{$args[0]} : @args;
 
     # set default class
     my @class_names = qw( fieldset_group
@@ -92,8 +92,10 @@ sub add_fieldset {
         if (ref $_args ne 'HASH');
 
     my $fieldset = HTML::FormBuilder::FieldSet->new(
-        data    => $_args,
-        classes => $self->{classes});
+        data     => $_args,
+        classes  => $self->classes,
+        localize => $self->localize
+    );
 
     push @{$self->{fieldsets}}, $fieldset;
 
@@ -249,7 +251,7 @@ sub set_field_value {
     my $input_field = $self->_get_input_field($field_id);
     return unless $input_field;
 
-    my $data = $input_field->{data};
+    my $data   = $input_field->{data};
     my $inputs = $data->{input};
 
     map {
@@ -291,7 +293,7 @@ sub get_field_value {
             }
             return unless $input->{type};
             if (   $input->{type} =~ /(?:text|textarea|password|hidden|file)/i
-                or $input->{type} eq 'checkbox' && $input->{checked} && $input->{checked} eq 'checked')
+                || $input->{type} eq 'checkbox' && $input->{checked} && $input->{checked} eq 'checked')
             {
                 return $input->{value};
             }
